(tutorials)=

# Tutorials

In the following, some tutorials using LightlyTrain can be found. The tutorials are a good starting point to learn about LightlyTrain.

```{toctree}
:maxdepth: 1

resnet/index
yolo/index
depth_estimation/index
```

We've also prepared some Google Colab notebooks for some packages we support. You can find them in the following page:

```{toctree}
:maxdepth: 1
colab/index
```
